@@ -37,6 +37,11 @@ class DecimalProperty(JsonProperty):
         return decimal.Decimal(obj)
 
     def unwrap(self, obj):
+        if isinstance(obj, (int, long)):
+            obj = decimal.Decimal(obj)
+        elif isinstance(obj, float):
+            # python 2.6 doesn't allow a float to Decimal
+            obj = decimal.Decimal(unicode(obj))
         assert isinstance(obj, decimal.Decimal)
         return obj, unicode(obj)
 
